==> estateplat-common-1.2.3-20180301.090929-36-sources.jar: cn/gtmap/estateplat/model/commodityHouse/contract/Spfwqbaqr.java <==
package cn.gtmap.estateplat.model.commodityHouse.contract;

import java.util.Date;

/**
 * Created by wushuheng on 2017/12/28.
 */
public class Spfwqbaqr {
    private String bdcdyh;//不动产单元号
    private String xmmc;//项目名称
    private String lpzl;//楼盘坐落
    private Integer zcs;//总层数
    private String szc;//所在层
    private Double jyjg;//交易价格
    private String jybz;//币种
    private Double jzmj;//建筑面积额
    private String fwyt;//房屋用途
    private String tdqlxz;//土地权利性质
    private String tdsyqxqs;//土地使用期限起始时间
    private String tdsyqxjs;//土地使用期限终止时间
    private Double tdsymj;//土地使用面积
    private String msr;//买受人
    private String sfh;//身份号
    private String csr;//出售人
    private String xydm;//信用代码
    private String bz;//备注


    public String getBdcdyh() {
        return bdcdyh;
    }
    public String getJybz() {
        return jybz;
    }

    public void setJybz(String jybz) {
        this.jybz = jybz;
    }
    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getXmmc() {
        return xmmc;
    }

    public void setXmmc(String xmmc) {
        this.xmmc = xmmc;
    }

    public String getLpzl() {
        return lpzl;
    }

    public void setLpzl(String lpzl) {
        this.lpzl = lpzl;
    }

    public Double getJyjg() {
        return jyjg;
    }

    public void setJyjg(Double jyjg) {
        this.jyjg = jyjg;
    }

    public Integer getZcs() {
        return zcs;
    }

    public void setZcs(Integer zcs) {
        this.zcs = zcs;
    }

    public Double getJzmj() {
        return jzmj;
    }

    public void setJzmj(Double jzmj) {
        this.jzmj = jzmj;
    }

    public String getFwyt() {
        return fwyt;
    }

    public void setFwyt(String fwyt) {
        this.fwyt = fwyt;
    }

    public String getTdqlxz() {
        return tdqlxz;
    }

    public void setTdqlxz(String tdqlxz) {
        this.tdqlxz = tdqlxz;
    }


    public Double getTdsymj() {
        return tdsymj;
    }

    public void setTdsymj(Double tdsymj) {
        this.tdsymj = tdsymj;
    }

    public String getTdsyqxqs() {
        return tdsyqxqs;
    }

    public void setTdsyqxqs(String tdsyqxqs) {
        this.tdsyqxqs = tdsyqxqs;
    }

    public String getTdsyqxjs() {
        return tdsyqxjs;
    }

    public void setTdsyqxjs(String tdsyqxjs) {
        this.tdsyqxjs = tdsyqxjs;
    }



    public String getMsr() {
        return msr;
    }

    public void setMsr(String msr) {
        this.msr = msr;
    }

    public String getSfh() {
        return sfh;
    }

    public void setSfh(String sfh) {
        this.sfh = sfh;
    }

    public String getCsr() {
        return csr;
    }

    public void setCsr(String csr) {
        this.csr = csr;
    }

    public String getXydm() {
        return xydm;
    }

    public void setXydm(String xydm) {
        this.xydm = xydm;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getSzc() {
        return szc;
    }

    public void setSzc(String szc) {
        this.szc = szc;
    }

}

==> estateplat-common-1.2.3-20180628.061424-132-sources.jar: cn/gtmap/estateplat/model/commodityHouse/contract/Spfwqbaqr.java <==
package cn.gtmap.estateplat.model.commodityHouse.contract;

import java.util.Date;

/**
 * Created by wushuheng on 2017/12/28.
 */
public class Spfwqbaqr {
    private String bdcdyh;//不动产单元号
    private String xmmc;//项目名称
    private String lpzl;//楼盘坐落
    private Integer zcs;//总层数
    private String szc;//所在层
    private Double jyjg;//交易价格
    private Double jydj;//交易价格
    private String jybz;//币种
    private Double jzmj;//建筑面积额
    private String fwyt;//房屋用途
    private String tdqlxz;//土地权利性质
    private String tdsyqxqs;//土地使用期限起始时间
    private String tdsyqxjs;//土地使用期限终止时间
    private Double tdsymj;//土地使用面积
    private String msr;//买受人
    private String msrdh;//买受人电话
    private String sfh;//身份号
    private String csr;//出售人
    private String xydm;//信用代码
    private String bz;//备注


    public String getBdcdyh() {
        return bdcdyh;
    }
    public String getJybz() {
        return jybz;
    }

    public void setJybz(String jybz) {
        this.jybz = jybz;
    }
    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getXmmc() {
        return xmmc;
    }

    public void setXmmc(String xmmc) {
        this.xmmc = xmmc;
    }

    public String getLpzl() {
        return lpzl;
    }

    public void setLpzl(String lpzl) {
        this.lpzl = lpzl;
    }

    public Double getJyjg() {
        return jyjg;
    }

    public void setJyjg(Double jyjg) {
        this.jyjg = jyjg;
    }

    public Double getJydj() {
        return jyjg;
    }

    public void setJydj(Double jydj) {
        this.jydj = jydj;
    }

    public Integer getZcs() {
        return zcs;
    }

    public void setZcs(Integer zcs) {
        this.zcs = zcs;
    }

    public Double getJzmj() {
        return jzmj;
    }

    public void setJzmj(Double jzmj) {
        this.jzmj = jzmj;
    }

    public String getFwyt() {
        return fwyt;
    }

    public void setFwyt(String fwyt) {
        this.fwyt = fwyt;
    }

    public String getTdqlxz() {
        return tdqlxz;
    }

    public void setTdqlxz(String tdqlxz) {
        this.tdqlxz = tdqlxz;
    }


    public Double getTdsymj() {
        return tdsymj;
    }

    public void setTdsymj(Double tdsymj) {
        this.tdsymj = tdsymj;
    }

    public String getTdsyqxqs() {
        return tdsyqxqs;
    }

    public void setTdsyqxqs(String tdsyqxqs) {
        this.tdsyqxqs = tdsyqxqs;
    }

    public String getTdsyqxjs() {
        return tdsyqxjs;
    }

    public void setTdsyqxjs(String tdsyqxjs) {
        this.tdsyqxjs = tdsyqxjs;
    }



    public String getMsr() {
        return msr;
    }

    public void setMsr(String msr) {
        this.msr = msr;
    }

    public String getMsrdh() {
        return msrdh;
    }

    public void setMsrdh(String msrdh) {
        this.msrdh = msrdh;
    }

    public String getSfh() {
        return sfh;
    }

    public void setSfh(String sfh) {
        this.sfh = sfh;
    }

    public String getCsr() {
        return csr;
    }

    public void setCsr(String csr) {
        this.csr = csr;
    }

    public String getXydm() {
        return xydm;
    }

    public void setXydm(String xydm) {
        this.xydm = xydm;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getSzc() {
        return szc;
    }

    public void setSzc(String szc) {
        this.szc = szc;
    }

}
